# Generated by Django 5.0.3 on 2024-03-27 05:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_bocor_ds', '0003_portfolio_redirect_link'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='portfolio',
            name='redirect_link',
        ),
    ]



from django.shortcuts import render, get_object_or_404, redirect
from django_utilsds import utils
from .forms import AppointmentForm
from _data import bocords
from .models import Portfolio

import logging
logger = logging.getLogger(__name__)
formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
ch = logging.StreamHandler()
ch.setFormatter(formatter)
logger.addHandler(ch)
logger.setLevel(logging.ERROR)


def robots(request):
    from django.shortcuts import HttpResponse
    file_content = utils.make_robots()
    return HttpResponse(file_content, content_type="text/plain")


def home(request):
    c = bocords.context

    logger.info(c)
    if request.method == 'GET':
        c.update({'form': AppointmentForm()})
        # 메일 전송 후에도 한동안 유지되는 anchor와 post_message를 바로 없애기 위해
        c['anchor'] = None
        c['post_message'] = None
        return render(request, 'bocords/index.html', c)
    elif request.method == "POST":
        c.update(make_post_context(request.POST, c['basic_info']['consult_email']))
        return render(request, 'bocords/index.html', c)


def make_post_context(request_post, consult_mail, anchor='appointment'):
    logger.info(request_post)
    context = {}
    # appointment 앱에서 post 요청을 처리함.
    logger.info(f'request.POST : {request_post}')
    form = AppointmentForm(request_post)
    # 템플릿 렌더링 후 바로 appointment 앵커로 이동시키기 위해 설정
    context['anchor'] = anchor
    if form.is_valid():
        name = form.cleaned_data['name']
        phone = form.cleaned_data['phone']
        date = form.cleaned_data['date']
        message = form.cleaned_data['message']
        logger.info(f'Pass validation test -  {name} {phone} {date} {message}')
        is_sendmail = utils.mail_to(title=f'{name} 고객 상담 문의',
                                    text=f'이름: {name}\n연락처: {phone}\n예약일: {date}\n메시지: {message}',
                                    mail_addr=consult_mail)
        if is_sendmail:
            context['post_message'] = '담당자에게 문의사항이 전달 되었습니다. 확인 후 바로 연락 드리겠습니다. 감사합니다.'
        else:
            context['post_message'] = '메일 전송에서 오류가 발생 하였습니다. 전화로 문의주시면 감사하겠습니다. 죄송합니다.'
        return context
    else:
        logger.error('Fail form validation test')
        context['post_message'] = '입력 항목이 유효하지 않습니다. 다시 입력해 주십시요.'
        return context


def details(request, id: int):
    url = get_object_or_404(Portfolio, pk=id).url
    return redirect(url)


# Generated by Django 5.0.3 on 2024-03-26 07:22

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('filter', models.CharField(max_length=20, verbose_name='카테고리')),
            ],
        ),
        migrations.CreateModel(
            name='Portfolio',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=20, verbose_name='제목')),
                ('subtitle', models.CharField(max_length=40, verbose_name='부제목')),
                ('description', models.TextField(blank=True, null=True, verbose_name='세부 설명')),
                ('image1', models.ImageField(help_text='각 이미지 비율이(3x5) 동일한 것이 보기 좋습니다.', null=True, upload_to='images/portfolio/')),
                ('image2', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image3', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image4', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image5', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('url', models.URLField(blank=True, help_text='공란 가능', max_length=500, null=True, verbose_name='참고링크')),
                ('filter', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='category', to='django_bocor_ds.category')),
            ],
        ),
    ]



from django.contrib import admin
from .models import Portfolio, Category

import django.contrib.auth.models
from django.contrib import auth


class PortfolioAdmin(admin.ModelAdmin):
    list_display = ('title', 'subtitle', 'filter')
    search_fields = ['title']


admin.site.register(Category)
admin.site.register(Portfolio, PortfolioAdmin)
try:
    admin.site.unregister(auth.models.User)
    admin.site.unregister(auth.models.Group)
except django.contrib.admin.sites.NotRegistered:
    pass




import datetime
from django import forms

# https://stackoverflow.com/questions/3367091/whats-the-cleanest-simplest-to-get-running-datepicker-in-django


class AppointmentForm(forms.Form):
    name = forms.CharField(
        label='', max_length=20,
        widget=forms.TextInput(attrs={'placeholder': '성함', 'class': 'form-control'})
    )
    email = forms.CharField(
        label='', max_length=20,
        widget=forms.TextInput(attrs={'placeholder': '이메일', 'class': 'form-control'})
    )
    company = forms.CharField(
        label='', max_length=20,
        widget=forms.TextInput(attrs={'placeholder': '업체명', 'class': 'form-control'})
    )
    message = forms.CharField(
        label='',
        required=False,
        widget=forms.Textarea(attrs={'placeholder': '문의사항',
                                     'class': 'form-control',
                                     'rows': '4'}))



# Generated by Django 5.0.3 on 2024-03-26 08:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_bocor_ds', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='portfolio',
            name='image3',
        ),
        migrations.RemoveField(
            model_name='portfolio',
            name='image4',
        ),
        migrations.RemoveField(
            model_name='portfolio',
            name='image5',
        ),
    ]



from django.template import Library, loader
from ..forms import AppointmentForm
from ..models import Portfolio, Category
from django.contrib.staticfiles import finders
import os

import logging
logger = logging.getLogger(__name__)
formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
ch = logging.StreamHandler()
ch.setFormatter(formatter)
logger.addHandler(ch)
logger.setLevel(logging.ERROR)


register = Library()

# https://localcoder.org/django-inclusion-tag-with-configurable-template


@register.simple_tag(takes_context=True)
def about(context):
    t = loader.get_template("bocords/_about.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def hero(context):
    t = loader.get_template(f"bocords/_hero.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def why_us(context):
    t = loader.get_template("bocords/_why_us.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def counts(context):
    t = loader.get_template("bocords/_counts.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def services(context):
    t = loader.get_template("bocords/_services.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


# 인클루전 태그는 동적으로 html파일을 할당할 수 없어서..
# https://localcoder.org/django-inclusion-tag-with-configurable-template

# 일반적인 방식의 심플태그는 csrf_token을 처리할 수 없어서...
# https://stackoverflow.com/questions/43787700/django-1-11-typeerror-context-must-be-a-dict-rather-than-context


@register.simple_tag(takes_context=True)
def appointment(context):
    t = loader.get_template("bocords/_appointment.html")
    context.update({
        'form': AppointmentForm(),
        'post_message': context.get('post_message', None),
        'naver_link': context.get('naver', None),
    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def features(context):
    t = loader.get_template("bocords/_features.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def team(context):
    t = loader.get_template("bocords/_team.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def faq(context):
    t = loader.get_template("bocords/_faq.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())

@register.simple_tag(takes_context=True)
def pricing(context):
    t = loader.get_template("bocords/_pricing.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())

@register.simple_tag(takes_context=True)
def testimonials(context):
    t = loader.get_template("bocords/_testimonials.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def gallery(context):
    t = loader.get_template("bocords/_gallery.html")

    # static 파일 경로 찾는 방법
    # https://stackoverflow.com/questions/30430131/get-the-file-path-for-a-static-file-in-django-code
    dir = finders.find('herobiz_ds/gallery')
    logger.info(f'gallery path: {dir}')

    files = []

    # static 갤러리 폴더안의 사진 파일의 수를 세어서 파일명을 리스트로 만든다.
    # https://www.delftstack.com/howto/python/count-the-number-of-files-in-a-directory-in-python/
    # https://stackoverflow.com/questions/3964681/find-all-files-in-a-directory-with-extension-txt-in-python
    if dir:
        for file in os.listdir(dir):
            if os.path.isfile(os.path.join(dir, file)) and file.endswith('.jpg'):
                files.append(file)
        logger.info(files)

    context.update({
        'gallery_files': files
    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def contact(context):
    t = loader.get_template("bocords/_contact.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def cta(context):
    t = loader.get_template("bocords/_cta.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def clients(context):
    t = loader.get_template("bocords/_clients.html")
    context.update({

    })
    logger.info(context)
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def portfolio(context):
    t = loader.get_template("bocords/_portfolio.html")
    context.update({
        'categories': Category.objects,
        'items': Portfolio.objects,
    })
    logger.info(context)
    return t.render(context.flatten())



# Generated by Django 5.0.3 on 2024-03-27 02:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_bocor_ds', '0002_remove_portfolio_image3_remove_portfolio_image4_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='portfolio',
            name='redirect_link',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='리다이렉트 링크'),
        ),
    ]



from django.urls import path
from . import views

app_name = 'bocords'

urlpatterns = [
    # robots.txt는 반드시 가장 먼저
    path('robots.txt', views.robots),
    path('', views.home, name='home'),
    path('<int:id>/', views.details, name='details'),
]
